@@ -221,7 +221,7 @@ search_entry_key_press_event_cb (GtkEntry    *entry,
 {
         DhSearchPriv *priv = GET_PRIVATE (search);
 
-        if (event->keyval == GDK_Tab) {
+        if (event->keyval == GDK_KEY_Tab) {
                 if (event->state & GDK_CONTROL_MASK) {
                         gtk_widget_grab_focus (priv->hitlist);
                 } else {
@@ -231,8 +231,8 @@ search_entry_key_press_event_cb (GtkEntry    *entry,
                 return TRUE;
         }
 
-        if (event->keyval == GDK_Return ||
-            event->keyval == GDK_KP_Enter) {
+        if (event->keyval == GDK_KEY_Return ||
+            event->keyval == GDK_KEY_KP_Enter) {
                 GtkTreeIter  iter;
                 DhLink      *link;
                 gchar       *name;
@@ -630,7 +630,7 @@ dh_search_new (DhBookManager *book_manager)
         book_label = gtk_label_new_with_mnemonic (_("Search in:"));
         gtk_label_set_mnemonic_widget (GTK_LABEL (book_label), priv->book_combo);
 
-        hbox = gtk_hbox_new (FALSE, 6);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         gtk_box_pack_start (GTK_BOX (hbox), book_label, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (hbox), priv->book_combo, TRUE, TRUE, 0);
         gtk_box_pack_start (GTK_BOX (search), hbox, FALSE, FALSE, 0);
