@@ -83,8 +83,8 @@ enum {
 static gint signals[LAST_SIGNAL] = { 0 };
 
 static guint tab_accel_keys[] = {
-        GDK_1, GDK_2, GDK_3, GDK_4, GDK_5,
-        GDK_6, GDK_7, GDK_8, GDK_9, GDK_0
+        GDK_KEY_1, GDK_KEY_2, GDK_KEY_3, GDK_KEY_4, GDK_KEY_5,
+        GDK_KEY_6, GDK_KEY_7, GDK_KEY_8, GDK_KEY_9, GDK_KEY_0
 };
 
 static const
@@ -745,8 +745,9 @@ window_activate_about (GtkAction *action,
                                "translator-credits",
                                strcmp (translator_credits, "translator_credits") != 0 ?
                                translator_credits : NULL,
-                               "website", "http://live.gnome.org/devhelp",
-                               "logo-icon-name", "devhelp",
+                               "website", PACKAGE_URL,
+                               "website-label", _("DevHelp Website"),
+                               "logo-icon-name", PACKAGE_TARNAME,
                                NULL);
 }
 
@@ -907,10 +908,10 @@ dh_window_init (DhWindow *window)
         accel_group = gtk_ui_manager_get_accel_group (priv->manager);
         gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 
-        priv->main_box = gtk_vbox_new (FALSE, 0);
+        priv->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (priv->main_box);
 
-        priv->menu_box = gtk_vbox_new (FALSE, 0);
+        priv->menu_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (priv->menu_box);
         gtk_container_set_border_width (GTK_CONTAINER (priv->menu_box), 0);
         gtk_box_pack_start (GTK_BOX (priv->main_box), priv->menu_box,
@@ -983,7 +984,7 @@ dh_window_init (DhWindow *window)
  */
 static void
 window_control_switch_page_cb (GtkWidget       *notebook,
-                               GtkNotebookPage *page,
+                               gpointer         page,
                                guint            page_num,
                                DhWindow        *window)
 {
@@ -998,7 +999,7 @@ window_control_switch_page_cb (GtkWidget       *notebook,
 
 static void
 window_control_after_switch_page_cb (GtkWidget       *notebook,
-                                     GtkNotebookPage *page,
+                                     gpointer         page,
                                      guint            page_num,
                                      DhWindow        *window)
 {
@@ -1013,7 +1014,7 @@ window_control_after_switch_page_cb (GtkWidget       *notebook,
 
 static void
 window_web_view_switch_page_cb (GtkNotebook     *notebook,
-                                GtkNotebookPage *page,
+                                gpointer         page,
                                 guint            new_page_num,
                                 DhWindow        *window)
 {
@@ -1051,7 +1052,7 @@ window_web_view_switch_page_cb (GtkNotebook     *notebook,
 
 static void
 window_web_view_switch_page_after_cb (GtkNotebook     *notebook,
-                                      GtkNotebookPage *page,
+                                      gpointer         page,
                                       guint            new_page_num,
                                       DhWindow        *window)
 {
@@ -1116,7 +1117,7 @@ window_populate (DhWindow *window)
         }
 #endif
 
-        priv->hpaned = gtk_hpaned_new ();
+        priv->hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 
         gtk_box_pack_start (GTK_BOX (priv->main_box), priv->hpaned, TRUE, TRUE, 0);
 
@@ -1168,7 +1169,7 @@ window_populate (DhWindow *window)
                           G_CALLBACK (window_search_link_selected_cb),
                           window);
 
-        priv->vbox = gtk_vbox_new (FALSE, 0);
+        priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_paned_add2 (GTK_PANED (priv->hpaned), priv->vbox);
 
         /* HTML tabs notebook. */
@@ -1643,7 +1644,7 @@ window_open_new_tab (DhWindow    *window,
         }
 #endif
 
-        vbox = gtk_vbox_new (0, FALSE);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox);
 
         /* XXX: Really it would be much better to use real structures */
@@ -1767,7 +1768,7 @@ window_new_tab_label (DhWindow        *window,
         GtkWidget *close_button;
         GtkWidget *image;
 
-        hbox = gtk_hbox_new (FALSE, 4);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 
         label = gtk_label_new (str);
         gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
